Module loqo

Module loqo 

LOQO mu oracle — port of IpLoqoMuOracle.{hpp,cpp}. Phase 10.

The LOQO rule chooses

  sigma = 0.1 * min(factor * (1 - xi) / xi, 2)^3
  mu_new = clamp(sigma * avrg_compl, mu_min, mu_max)

where xi = curr_centrality_measure() = min_compl / avrg_compl is a measure of how far the current iterate is from uniform complementarity, and factor = 0.05 per upstream’s hard-coded choice (IpLoqoMuOracle.cpp:52).

Structs

LoqoMuOracle